CHROMEDRIVER_CHROMIUM_URL = 'https://chromedriver.chromium.org'
CHROMEDRIVER_STORAGE_URL = 'https://chromedriver.storage.googleapis.com'

ZIP_TYPE = '.zip'

CHROMEDRIVER = 'chromedriver'
WEBDRIVER = 'webdriver'

CSS_VERSIONS_SELECTOR_UL = 'ul.n8H08c:nth-child(5)'

LATEST_STABLE_VERSION_STR = 'Latest stable release'
LATEST_BETA_VERSION_STR = 'Latest beta release'
